@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: callbacks_help.h,v 1.37 2004/06/06 19:22:48 jdepner Exp $
+ *  $Id: callbacks_help.h,v 1.39 2005/02/06 23:31:09 jdepner Exp $
  */
 
 #include "support.h"
@@ -84,8 +84,9 @@ here as well.  Up to 10 per second (default) and down to 0 (disabled).\n\
 are saved in the file $HOME/.jamin-defaults.  This is done whenever you \
 exit from JAMin.  You can actually edit this file and change the colors by \
 hand.  They are just RGB values in the 0-65535 range but it's much easier to \
-use the GUI ;-).  You may also set the crossfade time in this dialog (see the \
-man page for more information on crossfade time).\n\
+use the GUI ;-).  You may also set the crossfade time and crossover type in \
+this dialog (see the man page for more information on crossfade time and \
+crossover type).\n\
     For help on the rest of the GUI, context specific help can be obtained \
 by moving the mouse pointer into one of the tool areas (compressor, EQ, \
 limiter, input, etc) and pressing <Shift><F1>.\n")
@@ -123,8 +124,9 @@ char crossover_help[] = {N_(
 three sections.  It applies to the compressors and stereo widths. If the \
 crossovers are set to 500Hz and 5KHz then the first stereo width control and \
 compressor works for 25-500Hz, the second for 500Hz-5KHz, and the last for \
-5KHz-20KHz.  The crossover has no effect on the HDEQ.  However, the crossover \
-bars that are visible in the HDEQ serve as a visual reference.\n")
+5KHz-20KHz.  The crossover has no effect on the HDEQ unless one or more bands \
+are soloed.  The crossover bars that are visible in the HDEQ serve as a visual \
+reference.\n")
 };
 
 
@@ -141,14 +143,17 @@ mouse button on a GEQ control will reset the value to 0.0.\n")
 char input_help[] = {N_(
 "    The input section allows you to set the input gain to the JAMin system.  \
 You can also pan the input left or right.  Clicking the right mouse button on \
-the gain/balance control will reset the value to 0.0/centre.\n")
+the gain/balance control will reset the value to 0.0/centre.  Clicking the \
+right mouse button on the meters will reset the peak indicator to the current \
+level.\n")
 };
 
 
 char spectrum_help[] = {N_(
 "    The spectrum display shows the power spectrum of the signal in bands \
 that correspond to the frequency bands in the 30 band EQ (GEQ). In addition \
-it displays the maximum value reached for each band as a yellow line.\n")
+it displays the maximum value reached for each band as a (by default) blue \
+line.\n")
 };
 
 
@@ -202,7 +207,8 @@ char limiter_help[] = {N_(
 output to exceed the set level.  It \'looks ahead\' by the specified amount \
 in order to make a smooth transition as it nears the limit level.  Clicking \
 the right mouse button on the input or limit control will reset the value to \
-0.0.\n")
+0.0.  Clicking the right mouse button on the input or limit meters will \
+reset the peak indicator to the current level.\n")
 };
 
 
@@ -216,7 +222,8 @@ mouse button on the boost control will reset the value to 0.0.\n")
 char output_help[] = {N_(
 "    The output control allows you to decrease the output level.  The upper \
 level is 0dB.  Clicking the right mouse button on the output control will \
-reset the value to 0.0.\n")
+reset the value to 0.0.  Clicking the right mouse button on the meter will \
+reset the peak indicator to the current level.\n")
 };
 
 
@@ -234,8 +241,9 @@ char preferences_help[] = {N_(
 are saved in the file $HOME/.jamin-defaults.  This is done whenever you \
 exit from JAMin.  You can actually edit this file and change the colors by \
 hand.  They are just RGB values in the 0-65535 range but it's much easier to \
-use the GUI ;-).  You may also set the crossfade time in this dialog (see the \
-man page for more information on crossfade time).\n")
+use the GUI ;-).  You may also set the crossfade time and crossover type in \
+this dialog (see the man page for more information on crossfade time and \
+crossover type).\n")
 };
 
 
