@@ -1,7 +1,7 @@
 /*
  *  io.c -- JAMin I/O driver.
  *
- *  Copyright (C) 2003 Jack O'Quin.
+ *  Copyright (C) 2003, 2004 Jack O'Quin.
  *  
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -58,6 +58,8 @@
  *	+ JACK not running realtime
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -71,8 +73,10 @@
 #include <errno.h>
 #include <assert.h>
 #include <jack/jack.h>
+#ifdef HAVE_JACK_CREATE_THREAD
+#include <jack/thread.h>
+#endif
 
-#include "config.h"
 #include "ringbuffer.h"		/* uses <jack/ringbuffer.h>, if available */
 #include "process.h"
 #include "resource.h"
@@ -82,11 +86,12 @@
 #include "jackstatus.h"
 #include "state.h"
 #include "spectrum.h"
+#include "preferences.h"
 #include "debug.h"
 #include "help.h"
 #include "support.h"
 
-char *jamin_options = "dFf:n:hprTtvVs:c:";    /* valid JAMin options */
+char *jamin_options = "dFf:j:n:hprTtvVs:c:i";   /* valid JAMin options */
 char *pname;				      /* `basename $0` */
 int dummy_mode = 0;			      /* -d option */
 int all_errors_fatal = 0;		      /* -F option */
@@ -126,8 +131,10 @@ static jack_ringbuffer_t *in_rb[NCHANNELS];  /* input channel buffers */
 static jack_ringbuffer_t *out_rb[NCHANNELS]; /* output channel buffers */
 
 /* JACK connection data */
-jack_status_t jst = {0};		/* current JACK status */
+io_jack_status_t jst = {0};		/* current JACK status */
 jack_client_t *client;			/* JACK client structure */
+char *client_name = NULL;		/* JACK client name (in heap) */
+char *server_name = NULL;		/* JACK server name (in heap) */
 int nchannels = NCHANNELS;		/* actual number of channels */
 
 /* These arrays are NULL-terminated... */
@@ -222,9 +229,9 @@ void io_errlog(int err, char *fmt, ...)
 
     IF_DEBUG(DBG_TERSE,
 	     io_trace("error %d: %s", err, buffer));
-    fprintf(stderr, _("%s internal error %d: %s\n"), PACKAGE, err, buffer);
+    g_print(_("%s internal error %d: %s\n"), PACKAGE, err, buffer);
     if (all_errors_fatal) {
-	fprintf(stderr, _(" Terminating due to -F option.\n"));
+	g_print(_(" Terminating due to -F option.\n"));
 	abort();
     }
 }
@@ -273,7 +280,7 @@ void io_new_state(int next)
 
 
 /* io_get_status -- collect current JACK status. */
-void io_get_status(jack_status_t *jp)
+void io_get_status(io_jack_status_t *jp)
 {
     if (client)
 	jst.cpu_load = jack_cpu_load(client);
@@ -592,6 +599,16 @@ int io_bufsize(jack_nframes_t nframes, void *arg)
 }
 
 
+/* io_free_heap -- free heap entry, if allocated. */
+static inline void io_free_heap(char **p)
+{
+    if (*p) {				/* space allocated? */
+	free(*p);
+	*p = NULL;			/* mark space freed */
+    }
+}
+
+
 /* io_cleanup -- clean up all DSP I/O resources.
  *
  *  Called in main user interface thread after user requests "quit",
@@ -635,13 +652,15 @@ void io_cleanup()
     };	
 
     if (DSP_STATE_IS(DSP_STOPPING)) {
-	jack_client_t *client_save = client;
 
 	/* MUST stop using JACK services before jack_client_close() */
+	jack_client_t *client_save = client;
 	client = NULL;
 	jst.active = 0;
 	io_new_state(DSP_STOPPED);
 	jack_client_close(client_save);	/* leave the jack graph */
+	io_free_heap(&client_name);
+	io_free_heap(&server_name);
 
 	/* free the ring buffers */
 	for (chan = 0; chan < nchannels; chan++) {
@@ -674,9 +693,9 @@ gboolean check_file (char *optarg)
 
   if ((fp = fopen (optarg, "r")) == NULL)
     {
-      errstr = g_strdup_printf (_("File %s : %s\nUsing default."), optarg, 
+      errstr = g_strdup_printf(_("File %s : %s\nUsing default."), optarg, 
                                 strerror (errno));
-      fprintf (stderr, "%s\n", errstr);
+      g_print("%s\n", errstr);
       message (GTK_MESSAGE_ERROR, errstr);
       free (errstr);
       return (FALSE);
@@ -689,6 +708,50 @@ gboolean check_file (char *optarg)
 
 /****************  Initialization  ****************/
 
+/* io_jack_open -- open a connection with the JACK server
+ *
+ * Global variable client_name is a pointer to the client name string.
+ * This may be modified as a side-effect, if JACK assigns a different
+ * unique name for this session.
+ */
+jack_client_t *io_jack_open()
+{
+#ifdef HAVE_JACK_CLIENT_OPEN
+    jack_status_t status;
+
+    if (server_name) {
+	    client = jack_client_open(client_name, JackServerName,
+				      &status, server_name);
+    } else {
+	    client = jack_client_open(client_name, JackNullOption, &status);
+    }
+
+    if (client == NULL) {
+	g_print(_("%s: jack_client_open() failed, status = 0x%2.0x\n"),
+		PACKAGE, status);
+	return NULL;
+    }
+    if (status & JackServerStarted) {
+	g_print(_("%s: JACK server started\n"), PACKAGE);
+    }
+    if (status & JackNameNotUnique) {
+	client_name = strdup(jack_get_client_name(client));
+	g_print(_("%s: unique name `%s' assigned\n"), PACKAGE, client_name);
+    }
+
+#else /* !HAVE_JACK_CLIENT_OPEN */
+
+    client = jack_client_new(client_name);
+    if (client == NULL) {
+	g_print(_("%s: Cannot contact JACK server, is it running?\n"), PACKAGE);
+    }
+
+#endif /* HAVE_JACK_CLIENT_OPEN */
+
+    return client;
+
+}
+
 /* io_init -- initialize DSP engine.
  *
  *  DSP engine state transitions:
@@ -700,8 +763,6 @@ void io_init(int argc, char *argv[])
     int chan;
     int opt, spectrum_freq;
     float crossfade_time;
-    char *client_name = NULL;
-
 
     spectrum_freq = 10;
     crossfade_time = 1.0;
@@ -728,6 +789,9 @@ void io_init(int argc, char *argv[])
 		s_set_filename(session_file);
 	    }
             break;
+	case 'j':			/* Set JACK server name */
+	    server_name = strdup(optarg);
+	    break;
 	case 'n':			/* Set JACK client name */
 	    client_name = strdup(optarg);
 	    break;
@@ -755,6 +819,9 @@ void io_init(int argc, char *argv[])
 	case 'T':			/* list trace output */
 	    trace_option = 1;
 	    break;
+	case 'i':			/* Use IIR type crossover */
+            process_set_crossover_type (IIR);
+	    break;
 	case 'v':			/* verbose */
 	    debug_level += 1;		/* increment output level */
 	    break;
@@ -788,23 +855,24 @@ void io_init(int argc, char *argv[])
 	show_help = 1;
 
     if (show_help) {
-	fprintf(stderr, _(
+	g_print(_(
                 "Usage: %s [-%s] [inport1 inport2 [outport1 outport2]]\n"
                 "\nuser options:\n"
                 "\t-f file\tload session file on startup\n"
                 "\t-h\tshow this help\n"
-                "\t-n name\tset JACK client name\n"
+                "\t-j name\tJACK server name\n"
+                "\t-n name\tJACK client name\n"
                 "\t-s freq\tset spectrum update frequency\n"
-                "\t-c time\tset crossfade time\n"
+                "\t-c time\tcrossfade time\n"
                 "\t-r\tuse example GTK resource file\n"
-                "\t-p\tdon't automatically connect JACK output ports\n"
+                "\t-p\tdo not automatically connect JACK output ports\n"
                 "\t-v\tverbose output (use -vv... for more detail)\n"
-                "\t-V\tprint version and quit\n"
+                "\t-V\tprint JAMin version and quit\n"
                 "\ndeveloper options:\n"
-                "\t-d\tdummy mode (don't connect to jackd)\n"
+                "\t-d\tdummy mode (don't connect to JACK)\n"
                 "\t-F\ttreat all errors as fatal\n"
                 "\t-T\tprint trace buffer\n"
-                "\t-t\tdon't start DSP thread\n"
+                "\t-t\tdon't start separate DSP thread\n"
                 "\n"),
 		pname, jamin_options);
 	exit(1);
@@ -824,10 +892,8 @@ void io_init(int argc, char *argv[])
 	client_name = strdup(PACKAGE);
     }
 
-    client = jack_client_new(client_name);
-    if (client == 0) {
-	fprintf(stderr, _("%s: Cannot contact JACK server, is it running?\n"),
-		PACKAGE);
+    client = io_jack_open();
+    if (client == NULL) {
 	exit(2);
     }
 
@@ -844,8 +910,6 @@ void io_init(int argc, char *argv[])
 
     /* initialize process_signal() */
     process_init((float) jst.sample_rate);
-
-    free(client_name);
 }
 
 
@@ -857,9 +921,12 @@ int io_create_dsp_thread()
 {
     int rc;
     int policy;
-    struct sched_param rt_param, my_param;
+    struct sched_param rt_param;
     pthread_attr_t attributes;
     pthread_attr_init(&attributes);
+#ifndef HAVE_JACK_CREATE_THREAD
+    struct sched_param my_param;
+#endif
 
     /* Set priority and scheduling parameters based on the attributes
      * of the JACK client thread. */
@@ -884,6 +951,32 @@ int io_create_dsp_thread()
     } else
 	IF_DEBUG(DBG_TERSE, io_trace("JACK subsystem not realtime"));
 
+#ifdef HAVE_JACK_CREATE_THREAD		/* JACK thread support */
+#ifdef HAVE_JACK_CLIENT_CREATE_THREAD	/* newer interface */
+
+    rc = jack_client_create_thread(client, &dsp_thread, rt_param.sched_priority,
+				   jst.realtime, io_dsp_thread, NULL);
+
+#else  /* older interface */
+
+    rc = jack_create_thread(&dsp_thread, rt_param.sched_priority,
+			    jst.realtime, io_dsp_thread, NULL);
+
+#endif /* HAVE_JACK_CLIENT_CREATE_THREAD */
+
+    switch (rc) {
+    case 0:
+	IF_DEBUG(DBG_TERSE, io_trace("DSP thread created"));
+	break;
+    case EPERM:
+	io_errlog(EPERM, "no realtime privileges for DSP thread");
+	break;
+    default:
+	io_errlog(rc, "error creating DSP thread");
+    }
+
+#else  /* no JACK thread creation support */
+
     rc = pthread_attr_setschedpolicy(&attributes, policy);
     if (rc) {
 	io_errlog(EPERM, "cannot set scheduling policy, rc = %d.", rc);
@@ -968,11 +1061,11 @@ int io_create_dsp_thread()
     if (rc != 0) {
 	sched_setscheduler(0, policy, &my_param);
 
-        errstr = g_strdup_printf (
+        errstr = g_strdup_printf(
 	    _("%s: not permitted to create realtime DSP thread.\n"
 	      "\tYou must run as root or use JACK capabilities.\n"
 	      "\tContinuing operation, but with -t option.\n"), PACKAGE);
-        fprintf (stderr, "%s\n", errstr);
+        g_print(stderr, "%s\n", errstr);
         message (GTK_MESSAGE_WARNING, errstr);
         free (errstr);
 
@@ -984,10 +1077,11 @@ int io_create_dsp_thread()
     /* return this thread to the scheduler it used before */
     sched_setscheduler(0, policy, &my_param);
     IF_DEBUG(DBG_TERSE, io_trace("DSP thread finally created"));
-    return 0;
-#else /* !HAVE_POSIX_SCHED */
-    return rc;
+    rc = 0;
 #endif /* HAVE_POSIX_SCHED */
+#endif /* HAVE_JACK_CREATE_THREAD */
+
+    return rc;
 }
 
 
@@ -1019,13 +1113,13 @@ void io_activate()
 			       JackPortIsOutput, 0);
 
 	if (input_ports[chan] == NULL || output_ports[chan] == NULL) {
-	    fprintf(stderr, _("%s: Cannot register JACK ports."), PACKAGE);
+	    g_print(_("%s: Cannot register JACK ports."), PACKAGE);
 	    exit(2);
 	}
     }
 
     if (jack_activate(client)) {
-	fprintf(stderr, _("%s: Cannot activate JACK client."), PACKAGE);
+	g_print(_("%s: Cannot activate JACK client."), PACKAGE);
 	exit(2);
     }
 
@@ -1038,8 +1132,7 @@ void io_activate()
 
 	if (oports[0] == NULL) {	/* no output ports specified? */
 
-	    pports = jack_get_ports (client, ":playback", 
-				     JACK_DEFAULT_AUDIO_TYPE,
+	    pports = jack_get_ports (client, NULL, JACK_DEFAULT_AUDIO_TYPE,
 				     JackPortIsPhysical|JackPortIsInput);
 	    if (pports) {
 		/* use first `nchannels' physical playback ports */
@@ -1048,7 +1141,7 @@ void io_activate()
 		}
 	    } else {
 		errstr = g_strdup_printf(_("No physical playback ports found"));
-		fprintf (stderr, "%s\n", errstr);
+		g_print("%s\n", errstr);
 		message (GTK_MESSAGE_WARNING, errstr);
 		free (errstr);
 	    }
@@ -1058,9 +1151,9 @@ void io_activate()
 	    if (iports[chan] && *iports[chan]) {
 		if (jack_connect(client, iports[chan],
 				 jack_port_name(input_ports[chan]))) {
-                    errstr = g_strdup_printf (
+                    errstr = g_strdup_printf(
                         _("Cannot connect input port \"%s\"\n"), iports[chan]);
-                    fprintf (stderr, "%s\n", errstr);
+                    g_print("%s\n", errstr);
                     message (GTK_MESSAGE_WARNING, errstr);
                     free (errstr);
 		}
@@ -1068,9 +1161,9 @@ void io_activate()
 	    if (oports[chan] && *oports[chan]) {
 		if (jack_connect(client, jack_port_name(output_ports[chan]),
 				 oports[chan])) {
-                    errstr = g_strdup_printf (
+                    errstr = g_strdup_printf(
                         _("Cannot connect output port \"%s\"\n"), oports[chan]);
-                    fprintf (stderr, "%s\n", errstr);
+                    g_print("%s\n", errstr);
                     message (GTK_MESSAGE_WARNING, errstr);
                     free (errstr);
 		}
