@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: main.c,v 1.54 2004/05/26 23:23:27 joq Exp $
+ *  $Id: main.c,v 1.60 2005/02/20 15:58:49 jdepner Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -19,7 +19,7 @@
 #endif
 
 #ifdef HAVE_OSC
-#include <lo.h>
+#include <lo/lo.h>
 #include "constants.h"
 #endif
 
@@ -73,7 +73,6 @@ int scene_handler(const char *path, const char *types, lo_arg **argv, int argc,
 
 int main(int argc, char *argv[])
 {
-    char title[128];
 #ifdef HAVE_OSC
     lo_server_thread st;
 #endif
@@ -85,9 +84,10 @@ int main(int argc, char *argv[])
 #endif
 
     printf(PACKAGE " " VERSION "\n");
-    printf("(c) 2003 J. Depner, S. Harris, J. O'Quin, R. Parker and P. Shirkey\n");
-    printf("This is free software, and you are welcome to redistribute it\n" 
-	   "under certain conditions; see the file COPYING for details.\n");
+    g_print(_("(C) 2003-2005 J. Depner, S. Harris, J. O'Quin, R. Parker"
+	      " and P. Shirkey\n"));
+    g_print(_("This is free software, and you are welcome to redistribute it\n" 
+	      "under certain conditions; see the file COPYING for details.\n"));
 
     set_configuration_files();
     gtk_init(&argc, &argv);
@@ -101,8 +101,11 @@ int main(int argc, char *argv[])
     preferences_init();
     main_window = create_window1();
 
-    snprintf(title, sizeof(title), PACKAGE " " VERSION);
-    gtk_window_set_title ((GtkWindow *) main_window, title);
+
+#ifdef FILTER_TUNING
+    GtkWidget *ft = create_filter_tuning();
+    gtk_widget_show(ft);
+#endif
 
     //status_init();
 
@@ -125,8 +128,12 @@ int main(int argc, char *argv[])
 
 #ifdef HAVE_OSC
     st = lo_server_thread_new(OSC_PORT, error);
-    lo_server_thread_add_method(st, SCENE_URI, "i", scene_handler, NULL);
-    lo_server_thread_start(st);
+    if (st) {
+	lo_server_thread_add_method(st, SCENE_URI, "i", scene_handler, NULL);
+	lo_server_thread_start(st);
+    } else {
+	fprintf(stderr, "This " PACKAGE " instance will not have OSC support,\n"		"probably the port is allread in use\n");
+    }
 #endif
 
     /* start I/O processing, then run GTK main loop, until "quit" */
