@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: process.c,v 1.57 2004/07/17 10:38:23 theno23 Exp $
+ *  $Id: process.c,v 1.65 2004/10/28 08:20:33 theno23 Exp $
  */
 
 #include <math.h>
@@ -31,6 +31,10 @@
 #include "intrim.h"
 #include "io.h"
 #include "db.h"
+#include "denormal-kill.h"
+
+#define BIQUAD_TYPE double
+#include "biquad.h"
 
 #define BUF_MASK   (BINS-1)		/* BINS is a power of two */
 
@@ -51,6 +55,8 @@ lim_settings limiter;
 float eq_coefs[BINS]; /* Linear gain of each FFT bin */
 float lim_peak[2];
 
+static int iir_xover = 0;
+
 float in_peak[NCHANNELS], out_peak[NCHANNELS];
 
 static float band_f[BANDS];
@@ -58,7 +64,9 @@ static float gain_fix[BANDS];
 static float bin_peak[BINS];
 static int bands[BINS];
 static float in_buf[NCHANNELS][BINS];
+static float mid_buf[NCHANNELS][BINS];
 static float out_buf[NCHANNELS][XO_NBANDS][BINS];
+static biquad xo_filt[NCHANNELS][(XO_NBANDS-1) * 2];
 static float window[BINS];
 static fft_data *real;
 static fft_data *comp;
@@ -97,16 +105,20 @@ float sample_rate = 0.0f;
 /* Desired block size for calling process_signal(). */
 const jack_nframes_t dsp_block_size = BINS / OVER_SAMP;
 
-void run_eq(unsigned int port, unsigned int in_pos);
-void run_width(int xo_band, float *left, float *right, int nframes);
+#ifdef FILTER_TUNING
+float ft_bias_a_val = 1.0f;
+float ft_bias_a_hp_val = 1.0f;
+float ft_bias_b_val = 1.0f;
+float ft_bias_b_hp_val = 1.0f;
+float ft_rez_lp_a_val = 1.2;
+float ft_rez_hp_a_val = 1.2;
+float ft_rez_lp_b_val = 1.2;
+float ft_rez_hp_b_val = 1.2;
+#endif
 
-static inline void denormal_kill(float *v);
-static inline void denormal_kill(float *v)
-{
-    static const float offset = 1e-18f;
-    *v += offset;
-    *v -= offset;
-}
+void run_eq(unsigned int port, unsigned int in_pos);
+void run_eq_iir(unsigned int port, unsigned int in_pos);
+void run_width(int xo_band, float *left, float *right, int nframes);
 
 void process_init(float fs)
 {
@@ -163,10 +175,14 @@ void process_init(float fs)
     plan_rc = fftwf_plan_r2r_1d(BINS, real, comp, FFTW_R2HC, FFTW_MEASURE);
     plan_cr = fftwf_plan_r2r_1d(BINS, comp_tmp, real, FFTW_HC2R, FFTW_MEASURE);
 
-    /* Calculate raised cosine window */
+    /* Calculate root raised cosine window */
     for (i = 0; i < BINS; i++) {
-	window[i] = -0.5f * cosf(2.0f * M_PI * (float) i /
-				 (float) BINS) + 0.5f;
+       window[i] = -0.5f * cosf(2.0f * M_PI * (float) i /
+                                (float) BINS) + 0.5f;
+/* root rasied cosine window - aparently sounds worse ...
+	window[i] = sqrtf(0.5f + -0.5 * cosf(2.0f * M_PI * (float) i /
+			  (float) BINS));
+*/
     }
 
     plugin_init();
@@ -197,6 +213,9 @@ void process_init(float fs)
 	latcorbuf[i] = calloc(latcorbuf_len, sizeof(float));
 	latcorbuf_postcomp[i] = calloc(latcorbuf_len, sizeof(float));
     }
+
+    /* Clear the corssover filters state */
+    memset(xo_filt, 0, sizeof(xo_filt));
 }
 
 void run_eq(unsigned int port, unsigned int in_ptr)
@@ -294,6 +313,56 @@ void run_eq(unsigned int port, unsigned int in_ptr)
     }
 }
 
+/* this is like run_eq except that it only uses a FFT to do the EQ, 
+   the crossover is handled by IIR filters */
+
+void run_eq_iir(unsigned int port, unsigned int in_ptr)
+{
+    const float fix = 2.5f / ((float) BINS * (float) OVER_SAMP);
+    float peak;
+    unsigned int i, j;
+    int targ_bin;
+    float *peak_data;
+
+    for (i = 0; i < BINS; i++) {
+	real[i] = window[i] * in_buf[port][(in_ptr + i) & BUF_MASK];
+    }
+
+    fftwf_execute(plan_rc);
+
+    /* run the EQ + spectrum an. + xover process */
+
+    if (spectrum_mode == SPEC_PRE_EQ) {
+	peak_data = comp;
+    } else {
+	peak_data = comp_tmp;
+    }
+
+    memset(comp_tmp, 0, BINS * sizeof(fft_data));
+    targ_bin = xover_fa / sample_rate * ((float)BINS + 0.5f);
+
+    comp_tmp[0] = comp[0] * eq_coefs[0];
+    if (comp_tmp[0] > bin_peak[0]) bin_peak[0] = comp_tmp[0];
+    
+    for (i = 1; i < BINS / 2 - 1; i++) {
+	const float eq_gain = xo_band_action[XO_LOW] == MUTE ? 0.0f :
+				(eq_bypass ? 1.0f : eq_coefs[i]);
+
+	comp_tmp[i] = comp[i] * eq_gain;
+	comp_tmp[BINS - i] = comp[BINS - i] * eq_gain;
+
+	peak = sqrtf(peak_data[i] * peak_data[i] + peak_data[BINS - i] *
+		peak_data[BINS - i]);
+	if (peak > bin_peak[i]) {
+	    bin_peak[i] = peak;
+	}
+    }
+    fftwf_execute(plan_cr);
+    for (j = 0; j < BINS; j++) {
+	mid_buf[port][(in_ptr + j) & BUF_MASK] += real[j] * fix * window[j];
+    }
+}
+
 #define EPSILON 0.0000001f		/* small positive number */
 float bin_peak_read_and_clear(int bin)
 {
@@ -324,6 +393,29 @@ int process_signal(jack_nframes_t nframes,
     /* Crossfade parameter values from current to target */
     s_crossfade(nframes);
 
+    if (iir_xover) {
+	for (port = 0; port < nchannels; port++) {
+#ifdef FILTER_TUNING
+	    lp_set_params(&xo_filt[port][0], xover_fa * ft_bias_a_val,
+			   ft_rez_lp_a_val, sample_rate);
+	    hp_set_params(&xo_filt[port][1], xover_fa * ft_bias_a_hp_val,
+			   ft_rez_lp_a_val, sample_rate);
+	    lp_set_params(&xo_filt[port][2], xover_fb * ft_bias_b_val,
+			   ft_rez_lp_b_val, sample_rate);
+	    hp_set_params(&xo_filt[port][3], xover_fb * ft_bias_b_hp_val,
+			   ft_rez_lp_b_val, sample_rate);
+#else
+	    const double bw_a = 1.0/((60.0*(xover_fa/sample_rate))+0.5);
+	    const double bw_b = 1.0/((60.0*(xover_fb/sample_rate))+0.5);
+
+	    lp_set_params(&xo_filt[port][0], xover_fa, bw_a, sample_rate);
+	    hp_set_params(&xo_filt[port][1], xover_fa, bw_a, sample_rate);
+	    lp_set_params(&xo_filt[port][2], xover_fb, bw_b, sample_rate);
+	    hp_set_params(&xo_filt[port][3], xover_fb, bw_b, sample_rate);
+#endif
+	}
+    }
+
     for (pos = 0; pos < nframes; pos++) {
 	const unsigned int op = (in_ptr - latency) & BUF_MASK;
 	float amp;
@@ -357,12 +449,25 @@ printf("WARNING: wierd input: %f\n", in_buf[port][in_ptr]);
 		in_peak[port] = amp;
 	    }
 
-	    out_tmp[port][XO_LOW][pos] = out_buf[port][XO_LOW][op];
-	    out_buf[port][XO_LOW][op] = 0.0f;
-	    out_tmp[port][XO_MID][pos] = out_buf[port][XO_MID][op];
-	    out_buf[port][XO_MID][op] = 0.0f;
-	    out_tmp[port][XO_HIGH][pos] = out_buf[port][XO_HIGH][op];
-	    out_buf[port][XO_HIGH][op] = 0.0f;
+	    if (iir_xover) {
+		const float x = mid_buf[port][op];
+		const float a = biquad_run(&xo_filt[port][0], x);
+		const float y = biquad_run(&xo_filt[port][1], x);
+		const float b = biquad_run(&xo_filt[port][2], y);
+		const float c = biquad_run(&xo_filt[port][3], y);
+
+		out_tmp[port][XO_LOW][pos] = a;
+		out_tmp[port][XO_MID][pos] = b;
+		out_tmp[port][XO_HIGH][pos] = c;
+		mid_buf[port][op] = 0.0f;
+	    } else {
+		out_tmp[port][XO_LOW][pos] = out_buf[port][XO_LOW][op];
+		out_buf[port][XO_LOW][op] = 0.0f;
+		out_tmp[port][XO_MID][pos] = out_buf[port][XO_MID][op];
+		out_buf[port][XO_MID][op] = 0.0f;
+		out_tmp[port][XO_HIGH][pos] = out_buf[port][XO_HIGH][op];
+		out_buf[port][XO_HIGH][op] = 0.0f;
+	    }
 	}
 
 	in_ptr = (in_ptr + 1) & BUF_MASK;
@@ -374,14 +479,32 @@ printf("WARNING: wierd input: %f\n", in_buf[port][in_ptr]);
 		eq_bypass = eq_bypass_pending;
 		limiter_bypass = limiter_bypass_pending;
 
-		run_eq(CHANNEL_L, in_ptr);
-		run_eq(CHANNEL_R, in_ptr);
+		if (iir_xover) {
+		    run_eq_iir(CHANNEL_L, in_ptr);
+		    run_eq_iir(CHANNEL_R, in_ptr);
+		} else {
+		    run_eq(CHANNEL_L, in_ptr);
+		    run_eq(CHANNEL_R, in_ptr);
+		}
 	    }
 	    /* Work out when we can run it again */
 	    n_calc_pt = (in_ptr + dsp_block_size) & BUF_MASK;
 	}
     }
 
+    /* Handle solo and mute for the IIR crossove case */
+    if (iir_xover) {
+	for (port = 0; port < nchannels; port++) {
+	    for (band = XO_LOW; band < XO_NBANDS; band++) {
+		if (xo_band_action[band] == MUTE) {
+		    for (pos = 0; pos < nframes; pos++) {
+			out_tmp[port][band][pos] = 0.0f;
+		    }
+		}
+	    }
+	}
+    }
+
     //printf("rolled fifo's...\n");
 
     for (band = XO_LOW; band < XO_NBANDS; band++) {
@@ -399,7 +522,7 @@ printf("WARNING: wierd input: %f\n", in_buf[port][in_ptr]);
 	    out[port][pos] =
 		out_tmp[port][XO_LOW][pos] + out_tmp[port][XO_MID][pos] +
 		out_tmp[port][XO_HIGH][pos];
-		/* Keep buffer of compressor oputputs incase we need it for
+		/* Keep buffer of compressor outputs incase we need it for
 		 * limiter bypass */
 		latcorbuf_postcomp[port][(latcorbuf_pos + pos) &
 		    (latcorbuf_len - 1)] = out[port][pos];
@@ -578,6 +701,16 @@ void process_set_eq_bypass(int bypass)
     eq_bypass_pending = bypass;
 }
 
+void process_set_crossover_type(int type)
+{
+    iir_xover = type;
+}
+
+int process_get_crossover_type()
+{
+    return (iir_xover);
+}
+
 void process_set_limiter_bypass(int bypass)
 {
     limiter_bypass_pending = bypass;
